@@ -322,6 +322,15 @@ class FeatureAttributesBase(dict):
                     # Check type (int)
                     errors.extend(self._validate_dtype(data, feature, 'int64',
                                                        coerced_df, coerce=coerce))
+                elif 'data_type' not in attributes:
+                    # If feature is continuous with no data type, it should be numeric
+                    # if it cannot be casted to a float, then add an error
+                    if len(self._validate_dtype(data, feature, 'float64',
+                                                coerced_df, coerce=True)):
+                        errors.extend([f"Feature '{feature}' should be numeric"
+                                       " when 'type' is 'continuous' and "
+                                       "'data_type' is undefined."])
+
             # Check feature bounds
             if validate_bounds:
                 errors.extend(self._validate_bounds(data, feature, attributes))
@@ -444,7 +453,6 @@ class InferFeatureAttributesBase(ABC):
     def _process(self,  # noqa: C901
                  features: Optional[Dict[str, Dict]] = None,
                  infer_bounds: bool = True,
-                 dropna: bool = False,
                  tight_bounds: Optional[Iterable[str]] = None,
                  mode_bound_features: Optional[Iterable[str]] = None,
                  id_feature_name: Optional[Union[str, Iterable[str]]] = None,
@@ -494,6 +502,8 @@ class InferFeatureAttributesBase(ABC):
             # What type is this feature?
             feature_type, typing_info = self._get_feature_type(feature_name)
 
+            typing_info = typing_info or dict()
+
             # EXPLICITLY DECLARED ORDINALS
             if feature_name in ordinal_feature_values:
                 feature_attributes[feature_name] = {
@@ -656,13 +666,6 @@ class InferFeatureAttributesBase(ABC):
                 if bounds:
                     feature_attributes[feature_name]['bounds'] = bounds  # noqa
 
-        if dropna:
-            for feature_name in feature_attributes:
-                if 'dropna' in feature_attributes[feature_name]:
-                    # Don't override user's preference
-                    continue
-                feature_attributes[feature_name]['dropna'] = True  # noqa
-
         # Do any features contain data unsupported by the core?
         self._check_unsupported_data(feature_attributes)
 
@@ -1020,25 +1023,28 @@ class InferFeatureAttributesBase(ABC):
         -------
         True if the column values can be parsed into YAML.
         """
+        # If there is no data, return False
         first_non_none = self._get_first_non_null(feature)
         if first_non_none is None:
             return False
 
-        # Sample 30 random values
+        # Sample up-to 30 random values
         for _ in range(30):
-            rand_val = self._get_random_value(feature, no_nulls=True)
-            if rand_val is None:
+            sample = self._get_random_value(feature, no_nulls=True)
+
+            # Non-string types are not valid YAML documents on their own for
+            # the sake of infer_feature_attributes.
+            if not isinstance(sample, str):
                 return False
 
             # Try to parse rand_val as YAML
             try:
-                yaml.safe_load(rand_val)
-                if len(rand_val.split(':')) <= 1 or '\n' not in rand_val:
+                yaml.safe_load(sample)
+                if len(sample.split(':')) <= 1 or '\n' not in sample:
                     return False
-            except (yaml.YAMLError):
+            except yaml.YAMLError:
                 return False
 
-        # No exception: valid YAML
         return True
 
     @staticmethod
