@@ -6,7 +6,7 @@ import logging
 from math import ceil, isnan, log
 import re
 from typing import (
-    Any, Dict, Iterable, List, Mapping, Optional, Tuple, Union
+    Any, Dict, Iterable, List, Mapping, Optional, Tuple
 )
 import warnings
 
@@ -24,6 +24,7 @@ from ..features import FeatureType
 from ..utilities import (
     date_to_epoch,
     determine_iso_format,
+    epoch_to_date,
     ISO_8601_DATE_FORMAT,
     ISO_8601_FORMAT,
     time_to_seconds,
@@ -326,12 +327,14 @@ class InferFeatureAttributesSQLTable(InferFeatureAttributesBase):
                     random_value = (
                         session.query(self.data.c[feature_name])
                                .filter(self.data.c[feature_name].is_not(None))
-                               .offset(idx)
-                               .first()
+                               .order_by(feature_name)  # 19234: using order_by here is necessary for MSSQL,
+                               .offset(idx)             # however, this should ultimately be re-written to
+                               .first()                 # avoid the performance pentalty this imposes.
                     )
                 else:
                     random_value = (
                         session.query(self.data.c[feature_name])
+                               .order_by(feature_name)  # See above
                                .offset(idx)
                                .first()
                     )
@@ -756,6 +759,7 @@ class InferFeatureAttributesSQLTable(InferFeatureAttributesBase):
         output = None
         allow_null = True
         original_type = feature_attributes[feature_name]['original_type']
+        decimal_places = feature_attributes[feature_name].get('decimal_places')
 
         # Only integers by default do no allow nulls.
         if original_type.get('data_type') == FeatureType.INTEGER.value:
@@ -811,6 +815,15 @@ class InferFeatureAttributesSQLTable(InferFeatureAttributesBase):
                             f'bounds.')
                         return None
 
+                # Capture the timezone information, so it can be included
+                # in the conversion back from epoch.
+                min_date_tz = None
+                max_date_tz = None
+                if isinstance(min_date_obj, (datetime.datetime, datetime.time)):
+                    min_date_tz = min_date_obj.tzinfo
+                if isinstance(max_date_obj, (datetime.datetime, datetime.time)):
+                    max_date_tz = max_date_obj.tzinfo
+
                 # Convert the found date bounds to float seconds since Epoch
                 min_value = date_to_epoch(min_date_obj, format_dt)
                 max_value = date_to_epoch(max_date_obj, format_dt)
@@ -859,7 +872,10 @@ class InferFeatureAttributesSQLTable(InferFeatureAttributesBase):
                                 min_value = actual_min_value
                             if actual_max_value == mode_f:
                                 max_value = actual_max_value
-
+                # If this is a datetime feature, convert back from epoch time
+                if format_dt is not None:
+                    min_value = epoch_to_date(min_value, format_dt, min_date_tz)
+                    max_value = epoch_to_date(max_value, format_dt, max_date_tz)
                 output = {'min': min_value, 'max': max_value}
                 if not allow_null:
                     output['allow_null'] = False
@@ -875,6 +891,12 @@ class InferFeatureAttributesSQLTable(InferFeatureAttributesBase):
             if not allow_null:
                 output = {'allow_null': False}
 
+        if decimal_places is not None:
+            if 'max' in output:
+                output['max'] = round(output['max'], decimal_places)
+            if 'min' in output:
+                output['min'] = round(output['min'], decimal_places)
+
         return output
 
     def _parse_column_type(self, full_type_str: str) -> Tuple[str, dict]:
