@@ -51,7 +51,6 @@ from rich.progress import (
     TextColumn,
     TimeElapsedColumn,
 )
-from sklearn.model_selection import train_test_split
 
 logger = logging.getLogger(__name__)
 
@@ -443,12 +442,17 @@ def generate_dataframe(*, client: AbstractHowsoClient,
         end_time = datetime.now() + timedelta(seconds=timeout)
         cases = {"action": []}
         while datetime.now() < end_time:
-            if case := client.react(
+            if reaction := client.react(
                 trainee.id, action_features=feature_names,
                 num_cases_to_generate=1, desired_conviction=1.0,
                 generate_new_cases="no", suppress_warning=True
             ):
-                cases["action"].append(case["action"][0])
+                new_cases = reaction.get("action", [])
+                if isinstance(new_cases, pd.DataFrame):
+                    new_case = new_cases.iloc[0].tolist()
+                else:
+                    new_case = new_cases[0]
+                cases["action"].append(new_case)
         elapsed_time = timeout
     else:
         with Timer() as timer:
@@ -871,12 +875,16 @@ def check_engine_operation(
                                               num_samples=150)
 
         features = infer_feature_attributes(source_df)
-        X = source_df.drop("class", axis=1)
-        y = source_df["class"]
 
-        X_train, X_test, y_train, _ = train_test_split(X, y, test_size=0.2)
+        train_idx = source_df.sample(frac=0.8).index
+        df_train = source_df[source_df.index.isin(train_idx)]
+        df_test = source_df[~source_df.index.isin(train_idx)]
+        X_train = df_train.drop("class", axis=1)
+        y_train = df_train["class"]
+        X_test = df_test.drop("class", axis=1)
+
         action_features = ["class"]
-        context_features = X.columns.tolist()
+        context_features = X_train.columns.tolist()
         if not engine:
             raise AssertionError("Howso Engine™ is not installed.")
         trainee = engine.Trainee(
@@ -907,13 +915,12 @@ def check_engine_operation(
             pass
 
 
-def check_validator_enterprise_desirability(
+def check_validator_operation(
     *, registry: InstallationCheckRegistry,
     source_df: Optional[pd.DataFrame] = None,
-    desirability_threshold: float = 2.0
 ):
     """
-    Ensure that Validator-Enterprise operates as it should, returning relatively high desirability.
+    Ensure that Validator-Enterprise operates as it should.
 
     Parameters
     ----------
@@ -921,10 +928,6 @@ def check_validator_enterprise_desirability(
         The registry used to run this check.
     source_df : pd.DataFrame or None, default None
         Optional. If not provided a new dataframe will be synthesized.
-    desirability_threshold : float, default 3.0
-        The desirability threshold. If the run of Validator Enterprise
-        returns a desirability less than this value, the returned
-        Status will be WARNING.
 
     Returns
     -------
@@ -937,9 +940,8 @@ def check_validator_enterprise_desirability(
     if isinstance(Validator, Exception):
         print(Validator, file=registry.logger)
         return (Status.CRITICAL,
-                "Howso Data Quality Tool was not installed correctly. "
+                "Howso Validator™ was not installed correctly. "
                 "Please check installation.")
-    validator = None
     try:
         if source_df is None:
             source_df, _ = generate_dataframe(client=registry.client, num_samples=150)
@@ -949,25 +951,19 @@ def check_validator_enterprise_desirability(
         features = infer_feature_attributes(orig_df)
         if not Validator:
             raise AssertionError('Howso Validator™ is not installed.')
-        validator = Validator(orig_df, gen_df, features=features, verbose=-1)
-        desirability = validator.run_metric("DescriptiveStatistics").desirability
-        if desirability < desirability_threshold:
-            return (Status.WARNING, f"Desirability did not exceed the threshold of {desirability_threshold:,.1f}.")
+
+        with Validator(orig_df, gen_df, features=features, verbose=-1) as v:
+            result = v.run_metric("DescriptiveStatistics")
+
+        if result.desirability == 0 or len(result.errors):
+            return (Status.CRITICAL, "Validator encountered one or more errors.")
+
     except Exception:
         traceback.print_exc(file=registry.logger)
         return (Status.CRITICAL,
                 "Could not complete operation. Check installation.")
     else:
         return (Status.OK, "")
-    finally:
-        if validator:
-            for dataset in [validator.orig, validator.gen]:
-                if isinstance(dataset, Trainee):
-                    if id := getattr(dataset, "id", None):
-                        try:
-                            registry.client.release_trainee_resources(id)
-                        except Exception:  # noqa: Deliberately broad
-                            pass
 
 
 def _attempt_train_date_feature(result_queue: multiprocessing.Queue):
@@ -1119,10 +1115,10 @@ def configure(registry: InstallationCheckRegistry):
     )
 
     registry.add_check(
-        name="Howso Validator Enterprise: Desirability",
-        fn=partial(check_validator_enterprise_desirability, desirability_threshold=2.0),
+        name="Howso Validator: Basic operations",
+        fn=check_validator_operation,
         client_required="AbstractHowsoClient",
-        other_requirements=[Synthesizer, Validator],
+        other_requirements=[Validator],
     )
 
 
