@@ -5,6 +5,7 @@ Notice: These are internal utilities and are not intended to be
         referenced directly.
 """
 from collections import OrderedDict
+from collections.abc import Iterable
 from copy import deepcopy
 import datetime
 import decimal
@@ -14,7 +15,7 @@ import math
 import random
 import re
 from typing import (
-    Any, Dict, Generator, Iterable, List, Mapping, Optional, Tuple,
+    Any, Dict, Generator, Iterable, List, Mapping, NamedTuple, Optional, Tuple,
     TYPE_CHECKING, Union,
 )
 import unicodedata
@@ -223,12 +224,6 @@ def postprocess_feature_attributes(features):
         if feat is None:
             continue
 
-        # Backwards compatibility for non-sensitive
-        # TODO 15469 - Remove shim
-        if 'non-sensitive' in feat:
-            feat['non_sensitive'] = feat['non-sensitive']
-            del feat['non-sensitive']
-
         # Replace any instances of 'date_time_format' with the original python
         # format if it is defined
         if 'date_time_format' in feat:
@@ -276,18 +271,6 @@ def preprocess_feature_attributes(features):
         if feat is None:
             continue
 
-        # Shim to convert old "non-sensitive" properties to "non_sensitive"
-        # TODO 15469 - Remove shim
-        if 'non-sensitive' in feat:
-            feat['non_sensitive'] = feat['non-sensitive']
-            del feat['non-sensitive']
-            warnings.warn(
-                "The feature attribute 'non-sensitive' has been renamed to "
-                "'non_sensitive', support for using the previous name will "
-                "be removed in a future version.",
-                DeprecationWarning
-            )
-
         # Set decimal places to 0 when %S is in datetime format but %f is not.
         # This prevents core from returning microseconds
         try:
@@ -318,7 +301,7 @@ def preprocess_feature_attributes(features):
 
 def format_react_response(response, single_action=False):
     """
-    Reformat the react response into a dict of action and explanation.
+    Reformat the react response into a dict of action and details.
 
     Parameters
     ----------
@@ -330,7 +313,7 @@ def format_react_response(response, single_action=False):
     Returns
     -------
     dict
-        A dict of two keys, action and explanation.
+        A dict of two keys, action and details.
     """
     # Import locally to prevent a circular import
     from howso.utilities import replace_doublemax_with_infinity
@@ -352,10 +335,10 @@ def format_react_response(response, single_action=False):
             action = [dict(zip(action_features, values)) for
                       values in action_values]
 
-    # remove action_values from explanation to prevent output of dupe data
+    # remove action_values from details to prevent output of dupe data
     del response['action_values']
 
-    return {'action': action, 'explanation': response}
+    return {'action': action, 'details': response}
 
 
 def accumulate_react_result(accumulated_result, result):
@@ -679,23 +662,48 @@ class BatchScalingManager:
         datetime.timedelta(seconds=60), datetime.timedelta(seconds=75))
     # The batch size min and max (respectively)
     size_limits: Tuple[int, Optional[int]] = (1, None)
+    # Limit by memory usage of request or response size (respectively)
+    # In bytes, zero means no limit.
+    memory_limits: Tuple[int, int] = (10_000_000, 10_000_000)  # 10MB
+    # Prevent raising batch size when the size of the request or response
+    # (respectively) is within this range of the limit.
+    memory_limit_thresholds: Tuple[float, float] = (0.1, 0.1)  # 10%
     # The rate at which batches are scaled up and down (respectively)
     # See: https://en.wikipedia.org/wiki/Golden_ratio
     size_multiplier: Tuple[float, float] = (1.618, 0.809)
 
+    class SendOptions(NamedTuple):
+        """Options that can be passed to the generator."""
+
+        tick_duration: Optional[datetime.timedelta]
+        memory_sizes: Optional[Tuple[int, int]]
+
     def __init__(self, starting_size: int, progress_monitor: "ProgressTimer"):
         """Initialize a new BatchScalingManager instance."""
         self.starting_size = starting_size
         self.progress = progress_monitor
 
-    def gen_batch_size(self) -> Generator[int, Optional[datetime.timedelta],
-                                          None]:
+    @staticmethod
+    def send(
+        gen: Generator[int, Optional["SendOptions"], None],
+        options: SendOptions
+    ) -> Union[int, None]:
+        """Helper to send to generator and return None when stopped."""
+        try:
+            return gen.send(options)
+        except StopIteration:
+            return None
+
+    def gen_batch_size(self) -> Generator[int, Optional["SendOptions"], None]:
         """
         Returns a generator to get the next batch size.
 
-        When using "send" progress updating must be done manually and the
-        last tick duration should be provided as the parameter to "send". When
-        not using "send" progress updating will happen automatically.
+        When using "send" options with a tick_duration, progress updating must
+        be done manually and the last tick duration should be provided as
+        the parameter to "send". When not sending the tick_duration progress
+        updating will happen automatically. Additionally, the size of the
+        request and/or response can be provided via "send" to scale based on
+        memory usage.
         """
         if not self.progress.has_started:
             raise ValueError("Batching has not yet started")
@@ -704,35 +712,85 @@ class BatchScalingManager:
         while not self.progress.has_ended and not self.progress.is_complete:
             batch_size = self.clamp(batch_size, self.progress.current_tick,
                                     self.progress.total_ticks)
-            tick_duration = yield batch_size
+            options = yield batch_size
+            tick_duration = options.tick_duration if options else None
+            memory_sizes = options.memory_sizes if options else None
+
             if tick_duration is None:
                 # If send is not used, automatically update progress
                 tick_duration = self.progress.tick_duration
                 self.progress.update(batch_size)
-            batch_size = self.scale(batch_size, tick_duration)
+
+            batch_size = self.scale(batch_size, tick_duration, memory_sizes)
         return None
 
-    def scale(self, batch_size: int, batch_duration: datetime.timedelta) -> int:
+    def scale(
+        self,
+        batch_size: int,
+        batch_duration: Optional[datetime.timedelta],
+        memory_sizes: Optional[Tuple[int, int]]
+    ) -> int:
         """
-        Scale batch size based on duration of the batch.
+        Scale batch size based on duration or memory size of the batch.
 
         Parameters
         ----------
         batch_size : int
             The current batch size.
-        batch_duration : datetime.timedelta
+        batch_duration : datetime.timedelta or None
             The time the last batch took to complete.
+        memory_sizes : tuple of (int, int) or None
+            The request and response payload sizes. (respectively)
 
         Returns
         -------
         int
             The new batch size.
         """
-        if batch_duration <= self.time_threshold[0]:
+        if batch_duration is None:
+            batch_duration = datetime.timedelta(0)
+
+        adjust = None  # -1 = lower, 0/None = keep, 1 = raise
+
+        # Adjust based on memory sizes
+        # We use the threshold to prevent raising batch size when memory usage
+        # is in range of the limit.
+        max_in_mem, max_out_mem = self.memory_limits
+        in_mem, out_mem = memory_sizes or (0, 0)
+        mem_in_threshold, mem_out_threshold = self.memory_limit_thresholds
+        # Adjust based on request size
+        if max_in_mem and in_mem:
+            if in_mem > max_in_mem:
+                adjust = -1
+            elif (
+                adjust is None and
+                max_in_mem - (max_in_mem * mem_in_threshold) <= in_mem
+            ):
+                adjust = 0
+        # Adjust based on response size
+        if max_out_mem and out_mem:
+            if out_mem > max_out_mem:
+                adjust = -1
+            elif (
+                adjust is None and
+                max_out_mem - (max_out_mem * mem_out_threshold) <= out_mem
+            ):
+                adjust = 0
+
+        # Adjust based on duration
+        if adjust is None and batch_duration <= self.time_threshold[0]:
             # If took less than threshold, increase batch size
-            batch_size = math.ceil(batch_size * self.size_multiplier[0])
+            # Only raise when an adjustment has not already been set
+            adjust = 1
         elif batch_duration > self.time_threshold[1]:
             # If took longer than threshold, lower batch size
+            adjust = -1
+
+        if adjust == 1:
+            # Raise batch size
+            batch_size = math.ceil(batch_size * self.size_multiplier[0])
+        elif adjust == -1:
+            # Lower batch size
             if self.size_multiplier[1] < 1:
                 batch_size = math.floor(batch_size * self.size_multiplier[1])
             else:
@@ -774,7 +832,8 @@ def show_core_warnings(core_warnings):
 
     if isinstance(core_warnings, Iterable):
         for w in core_warnings:
-            warnings.warn(w.get('detail'), category=HowsoWarning)
+            if warning := w.get("detail"):
+                warnings.warn(warning, category=HowsoWarning)
 
 
 def to_pandas_datetime_format(f):
@@ -805,3 +864,49 @@ def to_pandas_datetime_format(f):
             # Failed to check pandas version
             pass
     return f
+
+
+class IgnoreWarnings:
+    """
+    Simple context manager to ignore Warnings.
+
+    Parameters
+    ----------
+    warning_types : Warning or Iterable of Warnings
+        The warning classes to ignore.
+    """
+
+    def __init__(
+        self,
+        warning_types: Union[Warning, Iterable[Warning]]
+    ):
+        """Initialize a new `catch_warnings` instance."""
+        self._catch_warnings = warnings.catch_warnings()
+        self._warning_types = warning_types
+
+        if not isinstance(self._warning_types, Iterable):
+            self._warning_types = [self._warning_types]
+        for warning_type in self._warning_types:
+            self._check_warning_class(warning_type)
+
+    @staticmethod
+    def _check_warning_class(warning_type):
+        """Check correct warning type."""
+        if not issubclass(warning_type, Warning):
+            warnings.warn(
+                f"{warning_type} is not a valid subclass of `Warning`. "
+                "Warnings will not be ignored."
+            )
+
+    def __enter__(self):
+        """Context entrance."""
+        # Enters the  `catch_warnings` instance.
+        self._catch_warnings.__enter__()
+        for warning_type in self._warning_types:
+            warnings.filterwarnings("ignore", category=warning_type)
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        """Context exit."""
+        self._catch_warnings.__exit__(exc_type, exc_value, traceback)
+        return False
